
%SCANTX   Krsek: Function for data obtaining from IR reflectin sensor
%
%       function [y, t] = scantx(sampper, maxsamp, timeout)
%
%       This function proces measuring and sample data preprocessing
%       on IR reflection sensor. THis sensor is connected to PC Lab card
%       Pcl812: A/D chanal 1 ... IR reciver (full range = 12V)
%               A/D chanal 2 ... Switch on probe (2V - push, 12V - else)
%       No input and output parameters are required. In this case the
%       default value is used. Function parameters:
%         y       ...   [Chan1, Chan2] IR reciver, switch. Rows
%                       coresponds to time.
%         t       ...   Time record (same number rows as y).
%         sampper ...   sampling period in seconds ( default 0.001s ).
%         maxsamp ...   max number samples which can be measured.
%                       ( default 10000 ).
%         timeout ...   time where the functionis waiting for hit of the
%                       switch on probe ( default 100s ).
%
%       See also:  Documentation.

%       Author       : Pavel Krsek, krsek@vision.felk.cvut.cz
%                      04/04/97 Computer Vision Laboratory,
%                      Czech Technical University, Prague
%       Documentation: This report
%       Language     : Matlab 4.2, (c) MathWorks
%       Last change  : 04/04/97
%       Status       : Ready
%

function [y, t] = scantx(sampper, maxsamp, timeout)

if (nargin <1), sampper = 0.001; end;
if (nargin <2), maxsamp = 10000; end;
if (nargin <3), timeout = 100/sampper; end;

%         *** Reset RT systemu ***
rtunload;               % odstran drive nahrane ovladace
rtload('pcl812')        % nahraj driver pro A/D kartu
rtclear;                % zrusi definice vsech casovacu

%         *** Nastaveni casovacu ***
rtdef(1,'in',sampper,[1 2]);    % Definuje casovac 1 pro vstup
                                % z kanalu 1 a 2 A/D karty.
rtdef(2,'in',sampper,[1 2]);    % Definuje casovac 2 pro vstup z kanalu
                                % 1 a 2 A/D karty (snimani tlacitka).

%         *** Definice historicke promenne ***
rtdef('y',maxsamp,2,1); % Definuje historickou promennou 'y'
                        % (misto v pamti pro maxsamp vzorku).
rtlink('y',1);          % Spoji 'y' s casovacem 1. Po spusteni
                        % casovace 1 se do 'y' zapisuji vzorky
                        % s periodou sampper az do jeho zastaveni.
                        % Pri preteceni se zacnou prepisovat od pocatku.

%         *** Spusteni casovace ***
rtstart(2);             % spust casovace 2 (kontrola stisku tlacitka)

%         *** Diagnostika chyb ***
y = rtrd(2,'Y');        % precteni dat z karty
if ((y(1) < 0.1) & (y(2) < 0.1)),
  rtstop all;
  rtunload;
  disp('Snimaci pripravek neni pravdepodobne zapnut.');
  disp('Zkontrolujte jeho zapnuti na zadni strane pocitace.');
  disp('(vypinac v poloze dole, sviti cervena dioda)');
  error('HW problem.');
 end;
if ((y(1) > 0.8) & (y(2) < 0.1)),
  rtstop all;
  rtunload;
  disp('Pravdepodobne drzite stale stisknute lacitko na sonde.');
  disp('Zkontrolujte si postup mereni a pokuste se jeste jednou.');
  disp('V pripade opakovane chyby zavolejte poverenou obsluhu.');
  error('HW problem.');
 end;
if ((y(1) <= 0.8) & (y(2) <= 0)),
  rtstop all;
  rtunload;
  disp('Pripravek neni pravdepodobne v poradku.');
  disp('Prosim zavolejte poverenou obsluhu.');
  error('HW problem.');
 end;

 %        *** Cekani na stisk tlacitka ***
%       ( ceka se nejdele do vyprseni timeout, pak se hlasi chyba)
while (rtrd(2,'T') < timeout) & (y(2) >= 0.5),
  y = rtrd(2,'Y');      %cteni dat z karty
 end;

%         *** Diagnostika chyb ***
if (rtrd(2,'T') >= timeout),
  rtstop all;
  rtunload;
  disp('Tlacitko na sonde nebylo v urcenem case stisknuto.')
  disp('Sonda neni pravdepodobne dobre pripojena.');
  disp('Zkontrolujte pripojeni a pokuste se mereni opakovat.');
  disp('Pokud se chyby bude opakovat zavolejte poverenou obsluhu.');
  error('HW problem.');
 end;

%         *** Mereni prubehu ***
rtstart(1);             % Spusti casovac - zacne zaznam do 'y'

% Ceka na pusteni tlacitka. Kontroluje se preplneni promenne 'y'.
t = rtrd(1,'T');
y = rtrd(2,'Y');
while (t <  maxsamp) & (y(2) <= 0.5),
  t = rtrd(1,'T');
  y = rtrd(2,'Y');
 end;

rtstop(1);              % Zastaveni obou casovacu
rtstop(2);              % KOnec mereni


if (t >= maxsamp),
  disp('Doslo k preplneni historicke promenne ''y'' - chybny prubeh.');
  disp('Priste skratte dobu mereni, nebo zvecte maxsamp');
 end;

clear y;
y = rtrd('y');          % Precteni vysledku z promenne 'y'

rtstop all;
rtclear;                % Vymazani dat RT systemu
rtunload;               % Odstrani nahrane ovladace z pamety
rtclear;

%                        *** Uprava namerenych dat ***
v = find(y(:,2)  < 0.5);
y = [y(v,1) y(v,2)];
ny = size(y);
t = [0:ny(1)-1];
t = t * sampper;

return               


